/*!
 * \file diomelf.c
 * \author Copyright 2009 by Bert Timmerman <bert.timmerman@xs4all.nl>
 * \brief Functions for DIOMELF SMT footprints.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.\n
 * \n
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.\n
 * \n
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.\n
 */


#include "register_functions.c"


/*!
 * \brief Create a list of DIOMELF packages with pre-defined values.
 *
 * The data in this list can be used in a combo box to select a
 * pre-defined package.
 * \n
 * <b>Parameters:</b> none.\n
 * \n
 * <b>Returns:</b> a list containing all package names of this footprint
 * type known by pcb-fpw.
 */
GList
diomelf_create_packages_list ()
{
        GList *diomelf_packages_list = NULL;
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF1911L");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF1911M");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF1911N");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3414L");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3414M");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3414N");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3515L");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3515M");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3515N");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3516L");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3516M");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3516N");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3520L");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3520M");
        diomelf_packages_list = g_list_append (diomelf_packages_list, "DIOMELF3520N");
        return (*diomelf_packages_list);
}


/*!
 * \brief Look up default values for a DIOMELF SMT footprint.
 *
 * Footprint values can be looked up by placing a question mark "?" in front
 * of the footprint name.\n
 * If the footprint name is recognised known values will be loaded and the
 * entries involved in the GUI will be updated accordingly.\n
 * Currently the following footprints are supported:\n
 * - DIOMELF1911L,
 * - DIOMELF1911M,
 * - DIOMELF1911N,
 * - DIOMELF3414L,
 * - DIOMELF3414M,
 * - DIOMELF3414N,
 * - DIOMELF3515L,
 * - DIOMELF3515M,
 * - DIOMELF3515N,
 * - DIOMELF3516L,
 * - DIOMELF3516M,
 * - DIOMELF3516N,
 * - DIOMELF3520L,
 * - DIOMELF3520M,
 * - DIOMELF3520N,
 *
 * \n
 * <b>Parameters:</b> \c *footprint_name a \c NULL terminated footprint
 * name.\n
 * \n
 * <b>Returns:</b> \c EXIT_SUCCESS when default values for a footprint
 * were found, \c EXIT_FAILURE when the footprint name was not found.
 */
int
diomelf_get_default_footprint_values
(
        gchar *footprint_name)
{
        if (!strcmp (footprint_name, "?DIOMELF1911L"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 2.00;
                package_body_width = 1.20;
                package_body_height = 1.20;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 1.90;
                pad_length = 0.55;
                pad_width = 1.30;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 0.20;
                silkscreen_width = 1.20;
                silkscreen_line_width = 0.20;
                courtyard_length = 2.70;
                courtyard_width = 1.50;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF1911L: is also known as MicroMELF."));
                footprint_name = g_strdup ("DIOMELF1911L");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF1911M"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 2.00;
                package_body_width = 1.20;
                package_body_height = 1.20;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 2.10;
                pad_length = 1.15;
                pad_width = 1.45;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 0.20;
                silkscreen_width = 1.20;
                silkscreen_line_width = 0.20;
                courtyard_length = 4.30;
                courtyard_width = 2.50;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF1911M: is also known as MicroMELF."));
                footprint_name = g_strdup ("DIOMELF1911M");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF1911N"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 2.00;
                package_body_width = 1.20;
                package_body_height = 1.20;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 2.00;
                pad_length = 0.85;
                pad_width = 1.35;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 0.20;
                silkscreen_width = 1.20;
                silkscreen_line_width = 0.20;
                courtyard_length = 3.40;
                courtyard_width = 1.90;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF1911N: is also known as MicroMELF."));
                footprint_name = g_strdup ("DIOMELF1911N");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3414L"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.60;
                package_body_width = 1.50;
                package_body_height = 1.50;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.20;
                pad_length = 0.85;
                pad_width = 1.55;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.60;
                silkscreen_width = 1.40;
                silkscreen_line_width = 0.20;
                courtyard_length = 4.30;
                courtyard_width = 1.80;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF3414L: is also known as LL-34."));
                footprint_name = g_strdup ("DIOMELF3414L");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3414M"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.60;
                package_body_width = 1.50;
                package_body_height = 1.50;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.40;
                pad_length = 1.40;
                pad_width = 1.75;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.30;
                silkscreen_width = 1.40;
                silkscreen_line_width = 0.20;
                courtyard_length = 5.80;
                courtyard_width = 2.80;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF3414M: is also known as LL-34."));
                footprint_name = g_strdup ("DIOMELF3414M");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3414N"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.60;
                package_body_width = 1.50;
                package_body_height = 1.50;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.30;
                pad_length = 1.10;
                pad_width = 1.65;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.50;
                silkscreen_width = 1.40;
                silkscreen_line_width = 0.20;
                courtyard_length = 4.90;
                courtyard_width = 2.20;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF3414N: is also known as SOD-80."));
                footprint_name = g_strdup ("DIOMELF3414N");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3515L"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 1.60;
                package_body_height = 1.60;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.40;
                pad_length = 0.75;
                pad_width = 1.70;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.90;
                silkscreen_width = 1.50;
                silkscreen_line_width = 0.20;
                courtyard_length = 4.40;
                courtyard_width = 1.90;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF3515L: is also known as IEC 100H01."));
                footprint_name = g_strdup ("DIOMELF3515L");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3515M"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 1.60;
                package_body_height = 1.60;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.60;
                pad_length = 1.30;
                pad_width = 1.85;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.60;
                silkscreen_width = 1.50;
                silkscreen_line_width = 0.20;
                courtyard_length = 5.90;
                courtyard_width = 2.90;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF3515M: is also known as IEC 100H01."));
                footprint_name = g_strdup ("DIOMELF3515M");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3515N"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 1.60;
                package_body_height = 1.60;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.50;
                pad_length = 1.00;
                pad_width = 1.75;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.80;
                silkscreen_width = 1.50;
                silkscreen_line_width = 0.20;
                courtyard_length = 5.00;
                courtyard_width = 2.30;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF3515N: is also known as IEC 100H01."));
                footprint_name = g_strdup ("DIOMELF3515N");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3516L"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 1.70;
                package_body_height = 1.70;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.20;
                pad_length = 0.95;
                pad_width = 1.80;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.50;
                silkscreen_width = 1.70;
                silkscreen_line_width = 0.20;
                courtyard_length = 4.40;
                courtyard_width = 2.00;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                footprint_name = g_strdup ("DIOMELF3516L");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3516M"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 1.70;
                package_body_height = 1.70;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.40;
                pad_length = 1.50;
                pad_width = 1.95;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.20;
                silkscreen_width = 1.70;
                silkscreen_line_width = 0.20;
                courtyard_length = 5.90;
                courtyard_width = 3.00;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                footprint_name = g_strdup ("DIOMELF3516M");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3516N"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 1.70;
                package_body_height = 1.70;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.30;
                pad_length = 1.20;
                pad_width = 1.85;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.40;
                silkscreen_width = 1.70;
                silkscreen_line_width = 0.20;
                courtyard_length = 5.00;
                courtyard_width = 2.40;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                footprint_name = g_strdup ("DIOMELF3516N");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3520L"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 2.10;
                package_body_height = 2.10;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.40;
                pad_length = 0.75;
                pad_width = 2.20;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.90;
                silkscreen_width = 2.10;
                silkscreen_line_width = 0.20;
                courtyard_length = 4.40;
                courtyard_width = 2.40;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                footprint_name = g_strdup ("DIOMELF3520L");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3520M"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 2.10;
                package_body_height = 2.10;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.60;
                pad_length = 1.30;
                pad_width = 2.35;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.60;
                silkscreen_width = 2.10;
                silkscreen_line_width = 0.20;
                courtyard_length = 5.90;
                courtyard_width = 3.40;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF3520M: is also known as IEC 100H03."));
                footprint_name = g_strdup ("DIOMELF3520M");
                return (EXIT_SUCCESS);
        }
        else if (!strcmp (footprint_name, "?DIOMELF3520N"))
        {
                pitch_y = 0.0;
                number_of_pins = 2;
                package_body_length = 3.70;
                package_body_width = 2.10;
                package_body_height = 2.10;
                package_is_radial = FALSE;
                number_of_columns = 0;
                number_of_rows = 0;
                pitch_x = 3.50;
                pad_length = 1.00;
                pad_width = 2.25;
                pad_shape = g_strdup ("rectangular pad");
                pad_shapes_type = SQUARE;
                thermal = FALSE;
                thermal_length = 0.0;
                thermal_width = 0.0;
                fiducial = FALSE;
                fiducial_pad_diameter = 0.0;
                fiducial_pad_solder_mask_clearance = 0.0;
                silkscreen_length = 1.80;
                silkscreen_width = 2.10;
                silkscreen_line_width = 0.20;
                courtyard_length = 5.00;
                courtyard_width = 2.80;
                courtyard_line_width = 0.05;
                count_x = 0;
                count_y = 0;
                footprint_units = g_strdup ("mm");
                g_free (footprint_name);
                g_log ("", G_LOG_LEVEL_INFO,
                        _("DIOMELF3520N: is also known as IEC 100H03."));
                footprint_name = g_strdup ("DIOMELF3520N");
                return (EXIT_SUCCESS);
        }
        else
        {
                g_log ("", G_LOG_LEVEL_WARNING,
                        _("default values for footprint %s not found.\n"),
                        footprint_name);
                return (EXIT_FAILURE);
        }
}


/*!
 * \brief Set GUI constraints for a DIOMELF SMT package type.
 *
 * <b>Parameters:</b> \c *widget is the caller widget.\n
 * \n
 * <b>Returns:</b> none.
 */
#if GUI
int
diomelf_set_gui_constraints (GtkWidget *widget)
{
        /* Widgets on tab 1 "Footprint" */
        GtkWidget *package_is_radial_checkbutton = lookup_widget (GTK_WIDGET (widget),
                "package_is_radial_checkbutton");
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (package_is_radial_checkbutton), FALSE);
        gtk_widget_set_sensitive (package_is_radial_checkbutton, FALSE);

        /* Widgets on tab 2 "Pins/Pads" */
        GtkWidget *number_of_columns_entry = lookup_widget (GTK_WIDGET (widget),
                "number_of_columns_entry");
        gtk_entry_set_text (GTK_ENTRY (number_of_columns_entry), "2");
        gtk_widget_set_sensitive (number_of_columns_entry, FALSE);
        GtkWidget *number_of_rows_entry = lookup_widget (GTK_WIDGET (widget),
                "number_of_rows_entry");
        gtk_entry_set_text (GTK_ENTRY (number_of_rows_entry), "1");
        gtk_widget_set_sensitive (number_of_rows_entry, FALSE);
        GtkWidget *count_x_entry = lookup_widget (GTK_WIDGET (widget),
                "count_x_entry");
        gtk_entry_set_text (GTK_ENTRY (count_x_entry), "");
        gtk_widget_set_sensitive (count_x_entry, FALSE);
        GtkWidget *count_y_entry = lookup_widget (GTK_WIDGET (widget),
                "count_y_entry");
        gtk_entry_set_text (GTK_ENTRY (count_y_entry), "");
        gtk_widget_set_sensitive (count_y_entry, FALSE);
        GtkWidget *number_1_position_entry = lookup_widget (GTK_WIDGET (widget),
                "number_1_position_entry");
        gtk_combo_box_set_active (GTK_COMBO_BOX (number_1_position_entry), UPPER_LEFT);
        gtk_widget_set_sensitive (number_1_position_entry, FALSE);

        /* Widgets on tab 5 "Heel & Toe goals" */
        gui_constraints_disable_heel_and_toe_goals_tab_widgets (widget);
}
#endif /* GUI */


/*!
 * \brief Write a footprint with two pads for a DIOMELF SMT package.
 *
 * <b>Parameters:</b> none.\n
 * \n
 * <b>Returns:</b> \c EXIT_FAILURE when errors were encountered,
 * \c EXIT_SUCCESS when OK.
 */
int
diomelf_write_footprint ()
{
        gdouble xmax;
        gdouble xmin;
        gdouble ymax;
        gdouble ymin;
        gdouble x_text;
        gdouble y_text;

        /* Determine (extreme) courtyard dimensions based on pin/pad
         * properties */
        xmin = multiplier * ((-pitch_x / 2.0) - (pad_length / 2.0) - pad_solder_mask_clearance);
        xmax = multiplier * (pitch_x / 2.0 + pad_length / 2.0 + pad_solder_mask_clearance);
        ymin = multiplier * ((-pad_width / 2.0) - pad_solder_mask_clearance);
        ymax = multiplier * (pad_width / 2.0 + pad_solder_mask_clearance);
        /* Determine (extreme) courtyard dimensions based on package
         * properties */
        if ((multiplier * ((-package_body_length / 2.0) - courtyard_clearance_with_package)) < xmin)
                xmin = (multiplier * ((-package_body_length / 2.0) - courtyard_clearance_with_package));
        if ((multiplier * ((package_body_length / 2.0) + courtyard_clearance_with_package)) > xmax)
                xmax = (multiplier * ((package_body_length / 2.0) + courtyard_clearance_with_package));
        if ((multiplier * ((-package_body_width / 2.0) - courtyard_clearance_with_package)) < ymin)
                ymin = (multiplier * ((-package_body_width / 2.0) - courtyard_clearance_with_package));
        if ((multiplier * ((package_body_width / 2.0) + courtyard_clearance_with_package)) > ymax)
                ymax = (multiplier * ((package_body_width / 2.0) + courtyard_clearance_with_package));
        /* If the user input is using even more real-estate then use it */
        if (multiplier * (-courtyard_length / 2.0) < xmin)
                xmin = multiplier * (-courtyard_length / 2.0);
        if (multiplier * (courtyard_length / 2.0) > xmax)
                xmax = multiplier * (courtyard_length / 2.0);
        if (multiplier * (-courtyard_width / 2.0) < ymin)
                ymin = multiplier * (-courtyard_width / 2.0);
        if (multiplier * (courtyard_width / 2.0) > ymax)
                ymax = multiplier * (courtyard_width / 2.0);
        /* Write element header
         * Guess for a place where to put the refdes text */
        x_text = 0.0 ; /* already in mil/100 */
        y_text = (ymin - 10000.0); /* already in mil/100 */
        write_element_header (x_text, y_text);
        /* Write pin and/or pad entities */
        if (!strcmp (pad_shape, "rectangular pad"))
                pin_pad_flags = g_strdup ("square");
        if (pad_length > pad_width) /* Write pads parallel to x-axis */
        {
                /* Pad #1 */
                write_pad
                (
                        1, /* pad number */
                        "C", /* pad name */
                        multiplier * ((-pitch_x - pad_length + pad_width) / 2.0), /* x0 coordinate */
                        0, /* y0-coordinate */
                        multiplier * ((-pitch_x + pad_length - pad_width) / 2.0), /* x1 coordinate */
                        0, /* y1-coordinate */
                        multiplier * pad_width, /* width of the pad */
                        multiplier * pad_clearance, /* clearance */
                        multiplier * (pad_width + (2 * pad_solder_mask_clearance)), /* solder mask clearance */
                        /* Write pin #1 with a square pad if checked */
                        (pin1_square) ? "square" : pin_pad_flags /* flags */
                );
                /* Pad #2 */
                write_pad
                (
                        2, /* pad number */
                        "A", /* pad name */
                        multiplier * ((pitch_x - pad_length + pad_width) / 2.0), /* x0 coordinate */
                        0, /* y0-coordinate */
                        multiplier * ((pitch_x + pad_length - pad_width) / 2.0), /* x1 coordinate */
                        0, /* y1-coordinate */
                        multiplier * pad_width, /* width of the pad */
                        multiplier * pad_clearance, /* clearance */
                        multiplier * (pad_width + (2 * pad_solder_mask_clearance)), /* solder mask clearance */
                        pin_pad_flags /* flags */
                );
        }
        else /* write pads perpendiclar to x-axis */
        {
                /* Pad #1 */
                write_pad
                (
                        1, /* pad number */
                        "C", /* pad name */
                        multiplier * (-pitch_x / 2.0), /* x0-coordinate */
                        multiplier * ((pad_width - pad_length) / 2.0), /* y0-coordinate */
                        multiplier * (-pitch_x / 2), /* x0-coordinate */
                        multiplier * ((-pad_width + pad_length) / 2.0), /* y1-coordinate */
                        multiplier * pad_length, /* width of the pad */
                        multiplier * pad_clearance, /* clearance */
                        multiplier * (pad_length + (2 * pad_solder_mask_clearance)), /* solder mask clearance */
                        /* Write pin #1 with a square pad if checked */
                        (pin1_square) ? "square" : pin_pad_flags /* flags */
                );
                /* Pad #2 */
                write_pad
                (
                        2, /* pad number */
                        "A", /* pad name */
                        multiplier * (pitch_x / 2.0), /* x1-coordinate */
                        multiplier * ((pad_width - pad_length) / 2.0), /* y0-coordinate */
                        multiplier * (pitch_x / 2.0), /* x1-coordinate */
                        multiplier * ((-pad_width + pad_length) / 2.0), /* y1-coordinate */
                        multiplier * pad_length, /* width of the pad */
                        multiplier * pad_clearance, /* clearance */
                        multiplier * (pad_length + (2 * pad_solder_mask_clearance)), /* solder mask clearance */
                        pin_pad_flags /* flags */
                );
        }
        /* Write a package body on the silkscreen */
        if (silkscreen_package_outline && (package_body_width))
        {
                fprintf (fp, "# Write a package body on the silkscreen\n");
                if (pad_width >= package_body_width)
                {
                        write_element_line
                        (
                                multiplier * (((-pitch_x + pad_length) / 2.0) + pad_solder_mask_clearance + silkscreen_line_width),
                                multiplier * (package_body_width / 2.0),
                                multiplier * (((pitch_x - pad_length) / 2.0) - pad_solder_mask_clearance - silkscreen_line_width),
                                multiplier * (package_body_width / 2.0),
                                multiplier * silkscreen_line_width
                        );
                        write_element_line
                        (
                                multiplier * (((-pitch_x + pad_length) / 2.0) + pad_solder_mask_clearance + silkscreen_line_width),
                                multiplier * (-package_body_width / 2.0),
                                multiplier * (((pitch_x - pad_length) / 2.0) - pad_solder_mask_clearance - silkscreen_line_width),
                                multiplier * (-package_body_width / 2.0),
                                multiplier * silkscreen_line_width
                        );
                }
                else
                {
                        /* lines parallel to X-axis */
                        write_element_line
                        (
                                multiplier * (-package_body_length / 2.0),
                                multiplier * (package_body_width / 2.0),
                                multiplier * (package_body_length / 2.0),
                                multiplier * (package_body_width / 2.0),
                                multiplier * silkscreen_line_width
                        );
                        write_element_line
                        (
                                multiplier * (-package_body_length / 2.0),
                                multiplier * (-package_body_width / 2.0),
                                multiplier * (package_body_length / 2.0),
                                multiplier * (-package_body_width / 2.0),
                                multiplier * silkscreen_line_width
                        );
                        /* lines perpendicular to X-axis */
                        write_element_line
                        (
                                multiplier * (-package_body_length / 2.0),
                                multiplier * (-package_body_width / 2.0),
                                multiplier * (-package_body_length / 2.0),
                                multiplier * (((-pad_width - silkscreen_line_width) / 2.0) - pad_solder_mask_clearance),
                                multiplier * silkscreen_line_width
                        );
                        write_element_line
                        (
                                multiplier * (-package_body_length / 2.0),
                                multiplier * (package_body_width / 2.0),
                                multiplier * (-package_body_length / 2.0),
                                multiplier * (((pad_width + silkscreen_line_width) / 2.0) + pad_solder_mask_clearance),
                                multiplier * silkscreen_line_width
                        );
                        write_element_line
                        (
                                multiplier * (package_body_length / 2.0),
                                multiplier * (-package_body_width / 2.0),
                                multiplier * (package_body_length / 2.0),
                                multiplier * (((-pad_width - silkscreen_line_width) / 2.0) - pad_solder_mask_clearance),
                                multiplier * silkscreen_line_width
                        );
                        write_element_line
                        (
                                multiplier * (package_body_length / 2.0),
                                multiplier * (package_body_width / 2.0),
                                multiplier * (package_body_length / 2.0),
                                multiplier * (((pad_width + silkscreen_line_width) / 2.0) + pad_solder_mask_clearance),
                                multiplier * silkscreen_line_width
                        );
                }
        }
        /* Write a pin #1 marker on the silkscreen */
        if (silkscreen_indicate_1)
        {
                fprintf (fp, "# Write a pin 1 marker on the silkscreen\n");
                if (pad_width >= package_body_width)
                {
                        write_element_line
                        (
                                multiplier * (((-pitch_x + pad_length) / 2.0) + pad_solder_mask_clearance + silkscreen_line_width),
                                multiplier * (-package_body_width / 2.0),
                                multiplier * (((-pitch_x + pad_length) / 2.0) + pad_solder_mask_clearance + silkscreen_line_width),
                                multiplier * (package_body_width / 2.0),
                                multiplier * silkscreen_line_width
                        );
                }
                else
                {
                        write_element_arc
                        (
                                multiplier * (((-package_body_length) / 2.0) - 2 * silkscreen_line_width),
                                multiplier * (-package_body_width / 2.0),
                                multiplier * 0.5 * silkscreen_line_width,
                                multiplier * 0.5 * silkscreen_line_width,
                                0,
                                360,
                                multiplier * silkscreen_line_width
                        );
                }
        }
        /* Write a courtyard on the silkscreen */
        if (courtyard)
        {
                fprintf (fp, "# Write a courtyard on the silkscreen\n");
                write_rectangle
                (
                        xmin, /* already in mil/100 */
                        ymin, /* already in mil/100 */
                        xmax, /* already in mil/100 */
                        ymax, /* already in mil/100 */
                        multiplier * courtyard_line_width
                );
        }
        return (EXIT_SUCCESS);
}


/*!
 * \brief A list containing all DIOMELF related functions.
 */
static fpw_function_t
diomelf_function_list[] =
{
#if GUI
        {
                "Set GUI constraints",
                diomelf_set_gui_constraints,
                "Set GUI constraints for a DIOMELF SMT package",
                NULL
        },
#endif /* GUI */
        {
                "Default Element Values",
                diomelf_get_default_footprint_values,
                "Get default values for a DIOMELF SMT package",
                NULL
        },
        {
                "Write footprint",
                diomelf_write_footprint,
                "Write a footprint for a DIOMELF SMT package",
                NULL
        }
};


/*!
 * \brief A list containing all DIOMELF related functions.
 */
REGISTER_FUNCTIONS (diomelf_function_list)


/*!
 * \brief Initialise by registering all DIOMELF related functions.
 *
 * <b>Parameters:</b> none.\n
 * \n
 * <b>Returns:</b> none.
 */
void
diomelf_init ()
{
        register_diomelf_function_list ();
}


/* EOF */
